"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const fs_1 = require("fs");
const rimraf_1 = require("rimraf");
const path_1 = require("path");
const Listr = require("listr");
const execa = require("execa");
function Task(path, projectName) {
    return new Listr([
        {
            title: "Download from git repository",
            task: () => execa.stdout("git", ["clone", "https://github.com/fullstackoverflow/Misc-exmaple.git", path]).then(result => {
                if (result !== "") {
                    throw new Error("Download error");
                }
                rimraf_1.sync(path_1.join(path, ".git"));
                const pkg = JSON.parse(fs_1.readFileSync(path_1.join(path, "package.json")).toString());
                pkg.name = projectName;
                fs_1.writeFileSync(path_1.join(path, "package.json"), JSON.stringify(pkg, null, 4));
            })
        },
        {
            title: "Install package dependencies with npm",
            task: () => execa("npm", ["install"], { cwd: path })
        }
    ]);
}
class NewProject extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(NewProject);
        let { path } = args;
        if (path) {
            if (!flags.force) {
                if (fs_1.existsSync(path) && fs_1.statSync(path).isDirectory()) {
                    if (fs_1.readdirSync(path).length > 0) {
                        const cover = await cli_ux_1.default.prompt("Directory is not empty,cover or not(Y/N)?");
                        if (cover === "N") {
                            return;
                        }
                        else if (cover === "Y") {
                            rimraf_1.sync("{*,.*}", {
                                glob: {
                                    cwd: path
                                }
                            });
                        }
                    }
                }
            }
            else {
                rimraf_1.sync("{*,.*}", {
                    glob: {
                        cwd: path
                    }
                });
            }
            const projectName = await cli_ux_1.default.prompt("What is the project name?");
            await Task(path, projectName).run();
            this.log(`project ${projectName} create success`);
        }
    }
}
NewProject.description = "create new project with misc";
NewProject.examples = [`$ misc new ./`];
NewProject.flags = {
    help: command_1.flags.help({ char: "h" }),
    force: command_1.flags.boolean({ char: "f" })
};
NewProject.args = [{ name: "path" }];
exports.default = NewProject;
